==> haskell-http-client-tls-0.3.5.1-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.1
id: http-client-tls-0.3.5.1-B88C2Qgis1J83dIQuGV0g2
key: http-client-tls-0.3.5.1-B88C2Qgis1J83dIQuGV0g2
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Client.TLS
abi: 33c3a04c0d4cc6fe2893e59153b62f4e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/http-client-tls-0.3.5.1
hs-libraries: HShttp-client-tls-0.3.5.1-B88C2Qgis1J83dIQuGV0g2
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    http-client-0.5.7.0-4QuVYRfpaKcGfvw6j7Qhek
    connection-0.2.8-JsxTLFF5rdCHokpL1Mazy6
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    tls-1.4.0-3vJa0ZMui2cIeZpfzEU1mu bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    transformers-0.5.2.0 http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    cryptonite-0.24-BP2rZy1LSzS3gXEkLCrB05
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=cbc023a13af0b49e672a5936ee9b18d1
             http-client-0.5.7.0-4QuVYRfpaKcGfvw6j7Qhek=b1c1b60aaf57aa09b663385b0c3175ee
             connection-0.2.8-JsxTLFF5rdCHokpL1Mazy6=fc3bb46175312bf21be7feb767ce8610
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=ef2cd2ee3956583f4f4dc001b18e6763
             tls-1.4.0-3vJa0ZMui2cIeZpfzEU1mu=d7f534a4eb670857ea5e7a8bd1f65063
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=f9fb05439242cab6e496c322f2a1e33a
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=8bdb3e32f976a0904554b35642e32260
             cryptonite-0.24-BP2rZy1LSzS3gXEkLCrB05=e50fee5376f84eba6e3440d0d6cc6f31
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=043e6b9ae4cdf12a535e82e4b354e645
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=62278cb6808dfdd4ea4dbd9b537b44e9
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=83774d660ce535b1c7a882f242c5fec6
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.5.1-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.1
id: http-client-tls-0.3.5.1-uf6b0TZIXQBSQCLLKSGy3
key: http-client-tls-0.3.5.1-uf6b0TZIXQBSQCLLKSGy3
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Client.TLS
abi: f0d13690ab8701d94cf02ae4702f9a1e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/http-client-tls-0.3.5.1
hs-libraries: HShttp-client-tls-0.3.5.1-uf6b0TZIXQBSQCLLKSGy3
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    http-client-0.5.7.0-4QuVYRfpaKcGfvw6j7Qhek
    connection-0.2.8-8SBywB2aNCo4BMi0n0mJWS
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    tls-1.4.0-6CluRDXMj6G5qEgLlQLZ3x bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    transformers-0.5.2.0 http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    cryptonite-0.24-ELENUw6Chsl82ACxm0cgXp
    memory-0.14.8-BAg3DtPwumR3TQfKUohmeR
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=cbc023a13af0b49e672a5936ee9b18d1
             http-client-0.5.7.0-4QuVYRfpaKcGfvw6j7Qhek=b1c1b60aaf57aa09b663385b0c3175ee
             connection-0.2.8-8SBywB2aNCo4BMi0n0mJWS=3d9a410f840c4cb15e42ec7125dca597
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=ef2cd2ee3956583f4f4dc001b18e6763
             tls-1.4.0-6CluRDXMj6G5qEgLlQLZ3x=0cf5fc109726fb04bbb8643630c4e74c
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=f9fb05439242cab6e496c322f2a1e33a
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=8bdb3e32f976a0904554b35642e32260
             cryptonite-0.24-ELENUw6Chsl82ACxm0cgXp=d36853e10cf2a0c9b1a6796b9ffe1717
             memory-0.14.8-BAg3DtPwumR3TQfKUohmeR=b78231a975bde8739839c13c0576fe77
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=62278cb6808dfdd4ea4dbd9b537b44e9
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=83774d660ce535b1c7a882f242c5fec6
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
